@@ -17,7 +17,9 @@ from ..auth import Auth, AuthList, Record
 from ..command import Response
 from ..context import CommandCtx, GuildMessageCtx, ManualAuthCtx, ManualAuthorCtx
 from ..errors import CommandError
+from aurcore.util import flattener
 
+flattener._DICT_FLATTEN_SEP = "."
 if ty.TYPE_CHECKING:
    from ..context import GuildAwareCtx
    from ..command import Command
@@ -33,6 +35,7 @@ class Builtins(FluxCog):
       "role"       : "role",
       "member"     : "member",
    }
+   name = "builtins"
 
    def load(self) -> None:
       async def parse_auth_id(ctx: GuildAwareCtx, type_: str, target_: str) -> int:
@@ -206,12 +209,13 @@ class Builtins(FluxCog):
          # ==
          _c = ctx.msg_ctx.dest
          _d = discord
-         _g: discord.Guild = ctx.msg_ctx.message.guild
+         # noinspection PyTypeChecker
+         _g: ty.Optional[discord.Guild] = ctx.msg_ctx.message.guild
          _b = _g.me
          with utils.Timer() as t:
             # noinspection PyBroadException
             try:
-               res = await exec_func(script, globals(), locals())
+               res = str(await exec_func(script, globals(), locals()))
             except Exception as e:
                res = re.sub(r'File ".*[\\/]([^\\/]+.py)"', r'File "\1"', traceback.format_exc(limit=1))
             res = res.replace(r"/home/zenith/.cache/pypoetry/virtualenvs/pinbot-AoGbOYTv-py3.9/lib/python3.9/site-packages", "...")
@@ -432,6 +436,29 @@ class Builtins(FluxCog):
          ) if voice_channels else ""
 
          embed.add_field(name="Public Voice Channels", value=f"[{len(voice_channels)} Channels]({public_vc_haste})", inline=True)
+
+         # Roles
+         roles = [role for role in g.roles]
+         public_roles_haste = await utils.haste(
+            self.flux.aiohttp_session,
+            content=tabulate.tabulate(
+               [[f"{role}",
+                 f"{role.id}",
+                 f"{role.position}",
+                 f"{role.color}",
+                 f"{role.created_at.strftime(utils.DATETIME_FMT_S)}",
+                 f"{len(role.members)}",
+                 f"{role.mentionable}",
+                 f"{role.hoist}",
+                 f"{role.managed}",
+                 ]
+                for role in roles],
+               headers=("Name", "ID", "Position", "Color Hex", "Creation Date", "# of visible members", "Mentionable", "Hoist", "Managed")
+
+            )
+         )
+         embed.add_field(name="Roles", value=f"[{len(roles)} Roles]({public_roles_haste})", inline=True)
+
          return Response(embed=embed)
          pass
 
@@ -504,6 +531,61 @@ class Builtins(FluxCog):
 
          return Response(embed=embed)
 
+      @self._commandeer(name="config", default_auths=[Record.allow_server_manager()])
+      async def __config(ctx: GuildCommandCtx, args: str):
+         """
+         config configpath (value)
+         ==
+         Configurate a setting
+         ==
+         configpath: config key
+         value: Value to set. prints info if empty
+         ==
+         :param ctx:
+         :param args:
+         :return:
+         """
+         if not args:
+            raise CommandError(f"Need to provide a config path. Available cogs: {','.join([cog.name for cog in self.flux.cogs])}")
+         config, value, *_ = [*args.split(" ", 1), None]
+         if (cfgroot := config.split(".", 1)[0]) not in [cog.name for cog in self.flux.cogs]:
+            raise CommandError(f"Cog name `{cfgroot or ' '}` not found in cogs: {','.join([cog.name for cog in self.flux.cogs])}")
+
+         if value is not None:
+            async with self.flux.CONFIG.writeable_conf(ctx.msg_ctx) as cfg:
+               t = cfg
+               for part in config.split("."):
+                  t = t[part]
+               if value in t:
+                  if not ctx.msg_ctx.validate_in_guild(t["type"], value):
+                     return f"{value} not recognizable as a {t['type']}"
+                  t["value"] = value
+                  return Response(f"Set {config} to `{value}`")
+               else:
+                  raise CommandError(f"`{config}` is a category, not a setting!")
+         else:
+            cfg = self.flux.CONFIG.of(ctx.msg_ctx)
+            t = cfg
+            for part in config.split("."):
+               t = t[part]
+            cfg_msg = [[f"{config}", f"{'(Category) ' if 'value' not in t.keys() else ''}{t['__meta']}"]]
+            for key in [k for k in t.keys() if k not in ('__meta', 'value')]:
+               cfg_msg.append([f"\n{config}.{key}", f"{'(Category) ' if 'value' not in t[key].keys() else ''}{t[key]['__meta']}"])
+            return Response(f"```{tabulate.tabulate(cfg_msg, headers=('Config Key', 'Info'))}```")
+
+      @self._commandeer(name="reload", allow_dm=True, default_auths=[Record.deny_all()])
+      async def __reload(ctx: CommandCtx, cog_name: str):
+         """
+         reload cogname
+         ==
+         ==
+         ==
+         :param ctx:
+         :param cog_name:
+         :return:
+         """
+         return Response(await self.flux.reload_cog(cog_name))
+
    @property
    def default_auths(self) -> ty.List[Record]:
       return []
