@@ -5,18 +5,20 @@ import aurcore as aur
 from loguru import logger
 from ..auth import AuthAware, Record
 from ..command import Command
+from aurcore.util import flattener
+
+flattener._DICT_FLATTEN_SEP = "."
 
 if ty.TYPE_CHECKING:
    from .. import FluxClient
    from ..context import GuildMessageCtx
-   from ..command import Response
    from ..types_ import *
-   from ..auth import Record
 
 
 class FluxCog(AuthAware, metaclass=abc.ABCMeta):
-   def __init__(self, flux: FluxClient, name: ty.Optional[str] = None):
-      self.name = name or self.__class__.__name__
+   name: str
+
+   def __init__(self, flux: FluxClient):
       self.flux = flux
       self.router = aur.EventRouter(self.name, host=self.flux.router.host)
       self.commands: ty.List[Command] = []
@@ -61,7 +63,8 @@ class FluxCog(AuthAware, metaclass=abc.ABCMeta):
 
    def teardown(self):
       logger.info(f"Cog {self.name} detaching from {self.router}")
-
+      # logger.info(list(zip(r.name, r.__hash__() for r in self.router.host.routers)))
+      print(self.router in self.router.host.routers)
       self.router.detach()
 
    @property
@@ -73,7 +76,8 @@ class FluxCog(AuthAware, metaclass=abc.ABCMeta):
       return []
 
    @abc.abstractmethod
-   def load(self): ...
+   def load(self) -> None:
+      ...
 
-   def __str__(self):
+   def __str__(self) -> str:
       return f"<Cog {self.name}>"
