@@ -58,6 +58,14 @@ class GuildAwareCtx(ConfigCtx):
    def config_identifier(self) -> str:
       return str(self.guild.id)
 
+   def validate_in_guild(self, _type: ty.Literal["member","channel","role"], raw: str):
+      if type == "member":
+         return self.guild.get_member(int(raw))
+      if type == "channel":
+         return self.guild.get_channel(int(raw))
+      if type == "role":
+         return self.guild.get_channel(int(raw))
+      return False
 
 # class GuildCommandCtx(CommandCtx, GuildAwareCtx):
 #    def __init__(self, guild: discord.Guild, **kwargs):
@@ -150,7 +158,7 @@ class GuildMemberCtx(AuthAwareCtx, GuildAwareCtx):
 class MessageCtx(AuthAwareCtx, AuthorAwareCtx, metaclass=ABCMeta):
    def __init__(self, flux: FluxClient, message: discord.Message, **kwargs: ty.Any):
       super().__init__(flux=flux, **kwargs)
-      self.message = message
+      self.message : discord.Message = message
 
    @property
    def author(self) -> ty.Union[discord.Member, discord.User]:
@@ -219,4 +227,4 @@ class GuildMessageCtx(GuildTextChannelCtx, MessageCtx, GuildMemberCtx):
 
 class DMMessageCtx(DMChannelCtx, MessageCtx):
    def __init__(self, **kwargs):
-      super().__init__(**kwargs)
+      super().__init__(**kwargs)
\ No newline at end of file
